@@ -12,7 +12,7 @@ use Class::Tiny {
 
 use constant MAXWORDLENGTH => 50; ## no critic ( ProhibitConstantPragma )
 
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 our %Wordlist; ## no critic ( Variables::ProhibitPackageVars )
 
@@ -78,12 +78,12 @@ sub strip_stopwords {
 		if   ( $word =~ s/('s)$//s ) { $trailing = $1 . $trailing }
 
 		if (
+			# if it looks like it starts with a sigil, etc.
 			$word =~ m/^[\&\%\$\@\:\<\*\\\_]/s
 
-			# if it looks like it starts with a sigil, etc.
+			# or contains anything strange
 			or $word =~ m/[\%\^\&\#\$\@\_\<\>\(\)\[\]\{\}\\\*\:\+\/\=\|\`\~]/
 
-			# or contains anything strange
 		  )
 		{
 			print "rejecting {$word}\n" if $self->_is_debug && $word ne '_';
@@ -95,6 +95,23 @@ sub strip_stopwords {
 				print " [Rejecting \"$word\" as a stopword]\n"
 					if $self->_is_debug;
 			}
+			elsif ( $word =~ /-/ ) {
+				# check individual parts
+				my @keep;
+				for my $part ( split /-/, $word ) {
+					if ( exists $stopwords->{$part} or exists $stopwords->{ lc $part } )
+					{
+						print " [Rejecting \"$part\" as a stopword]\n"
+							if $self->_is_debug;
+					}
+					else {
+						push @keep, $part;
+					}
+				}
+				if ( @keep ) {
+					$out .= $leading . join( "-", @keep ) . "$trailing ";
+				}
+			}
 			else {
 				$out .= "$leading$word$trailing ";
 			}
@@ -118,7 +135,7 @@ Pod::Wordlist - English words that come up in Perl documentation
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 DESCRIPTION
 
